@@ -5,9 +5,7 @@ import yaml
 from markdownup.helpers import rget
 
 default_config = {
-    'main': {
-        'theme': 'default'
-    },
+    'theme': 'default',
     'wsgi': {
         'bind': '127.0.0.1:8080',
         'workers': 1
@@ -27,6 +25,9 @@ default_config = {
         ],
         'gits': {}
     },
+    'access': {
+        'filename': '.upaccess'
+    },
     'markdown': {
         'extensions': {
             'extra': {},
