@@ -20,7 +20,9 @@ class Directory(Entry):
 
         for entry in self.path.iterdir():
             str_path = str('/' / entry.relative_to(context.root_path))
-            if any(map(lambda exclusion: exclusion.search(str_path), self.context.exclusions)):
+            exclusion = next((exclusion for exclusion in context.exclusions if exclusion.search(str_path)), None)
+            if exclusion:
+                print(f'Excluding {entry} due to configured exclusion pattern  {exclusion.pattern}')
                 continue
             name = entry.name
             if entry.is_file() and name.endswith('.md'):
@@ -49,8 +51,9 @@ class Directory(Entry):
 
     def resolve(self, environ, path: Path) -> Optional[File]:
         str_path = str('/' / path)
-        if any(map(lambda exclusion: exclusion.search(str_path), self.context.exclusions)):
-            print(f'Access denied through global rules for {str_path}')
+        exclusion = next((exclusion for exclusion in self.context.exclusions if exclusion.search(str_path)), None)
+        if exclusion:
+            print(f'Not resolving {str_path} because it matched configured exclusion pattern {exclusion.pattern}')
             return None
         self._reset()
         return self._resolve(environ, list(path.parts))
@@ -67,7 +70,7 @@ class Directory(Entry):
         elif next_part in self.directory_map:
             return self.directory_map[next_part]._resolve(environ, parts)
         else:
-            asset_file_path = self.path / next_part
+            asset_file_path = self.path / next_part / '/'.join(parts)
             if asset_file_path.is_file():
                 return AssetFile(asset_file_path)
             else:
@@ -97,9 +100,9 @@ class Directory(Entry):
     def is_accessible(self, environ):
         if self.access_roles is None:
             return True  # no access rules defined, access allowed
-        if 'roles' not in environ:
+        if 'authenticated' not in environ['auth']:
             return False  # access rules defined but user has no roles, access denied
-        if self.access_roles & environ['roles']:
+        if self.access_roles & environ['auth']['authenticated']['roles']:  # TODO find first match is probably a faster
             return True  # overlap between access roles and user roles, access allowed
         else:
             return False  # no intersect between access roles and user roles, access denied
